//
//  HttpHeader.swift
//  SwiftHttp
//
//  Created by Tibor Bodecs on 2022. 01. 03..
//

import Foundation

///
/// Common HTTP header keys
///
/// For more details, please visit: [iana.org](https://www.iana.org/assignments/message-headers/message-headers.xhtml)
///
public enum HttpHeader: String {

    /// Authorization header
    case authorization = "Authorization"
    
    /// Accept header
    case accept = "Accept"

    /// Permanent Message Header Field Names
    case acceptLanguage = "Accept-Language"
    case alsoControl = "Also-Control"
    case alternateRecipient = "Alternate-Recipient"
    case approved = "Approved"
    case aRCAuthenticationResults = "ARC-Authentication-Results"
    case aRCMessageSignature = "ARC-Message-Signature"
    case aRCSeal = "ARC-Seal"
    case archive = "Archive"
    case archivedAt = "Archived-At"
    case articleNames = "Article-Names"
    case articleUpdates = "Article-Updates"
    case authenticationResults = "Authentication-Results"
    case autoSubmitted = "Auto-Submitted"
    case autoforwarded = "Autoforwarded"
    case autosubmitted = "Autosubmitted"
    case base = "Base"
    case bcc = "Bcc"
    case body = "Body"
    case cancelKey = "Cancel-Key"
    case cancelLock = "Cancel-Lock"
    case cc = "Cc"
    case comments = "Comments"
    case contentAlternative = "Content-Alternative"
    case contentBase = "Content-Base"
    case contentDescription = "Content-Description"
    case contentDisposition = "Content-Disposition"
    case contentDuration = "Content-Duration"
    case contentfeatures = "Content-features"
    case contentID = "Content-ID"
    case contentIdentifier = "Content-Identifier"
    case contentLanguage = "Content-Language"
    case contentLocation = "Content-Location"
    case contentMD5 = "Content-MD5"
    case contentReturn = "Content-Return"
    case contentTransferEncoding = "Content-Transfer-Encoding"
    case contentTranslationType = "Content-Translation-Type"
    case contentType = "Content-Type"
    case control = "Control"
    case conversion = "Conversion"
    case conversionWithLoss = "Conversion-With-Loss"
    case dLExpansionHistory = "DL-Expansion-History"
    case date = "Date"
    case dateReceived = "Date-Received"
    case deferredDelivery = "Deferred-Delivery"
    case deliveryDate = "Delivery-Date"
    case discardedX400IPMSExtensions = "Discarded-X400-IPMS-Extensions"
    case discardedX400MTSExtensions = "Discarded-X400-MTS-Extensions"
    case discloseRecipients = "Disclose-Recipients"
    case dispositionNotificationOptions = "Disposition-Notification-Options"
    case dispositionNotificationTo = "Disposition-Notification-To"
    case distribution = "Distribution"
    case dKIMSignature = "DKIM-Signature"
    case downgradedBcc = "Downgraded-Bcc"
    case downgradedCc = "Downgraded-Cc"
    case downgradedDispositionNotificationTo = "Downgraded-Disposition-Notification-To"
    case downgradedFinalRecipient = "Downgraded-Final-Recipient"
    case downgradedFrom = "Downgraded-From"
    case downgradedInReplyTo = "Downgraded-In-Reply-To"
    case downgradedMailFrom = "Downgraded-Mail-From"
    case downgradedMessageId = "Downgraded-Message-Id"
    case downgradedOriginalRecipient = "Downgraded-Original-Recipient"
    case downgradedRcptTo = "Downgraded-Rcpt-To"
    case downgradedReferences = "Downgraded-References"
    case downgradedReplyTo = "Downgraded-Reply-To"
    case downgradedResentBcc = "Downgraded-Resent-Bcc"
    case downgradedResentCc = "Downgraded-Resent-Cc"
    case downgradedResentFrom = "Downgraded-Resent-From"
    case downgradedResentReplyTo = "Downgraded-Resent-Reply-To"
    case downgradedResentSender = "Downgraded-Resent-Sender"
    case downgradedResentTo = "Downgraded-Resent-To"
    case downgradedReturnPath = "Downgraded-Return-Path"
    case downgradedSender = "Downgraded-Sender"
    case downgradedTo = "Downgraded-To"
    case encoding = "Encoding"
    case encrypted = "Encrypted"
    case expires = "Expires"
    case expiryDate = "Expiry-Date"
    case followupTo = "Followup-To"
    case from = "From"
    case generateDeliveryReport = "Generate-Delivery-Report"
    case importance = "Importance"
    case inReplyTo = "In-Reply-To"
    case incompleteCopy = "Incomplete-Copy"
    case injectionDate = "Injection-Date"
    case injectionInfo = "Injection-Info"
    case keywords = "Keywords"
    case language = "Language"
    case latestDeliveryTime = "Latest-Delivery-Time"
    case lines = "Lines"
    case listArchive = "List-Archive"
    case listHelp = "List-Help"
    case listID = "List-ID"
    case listOwner = "List-Owner"
    case listPost = "List-Post"
    case listSubscribe = "List-Subscribe"
    case listUnsubscribe = "List-Unsubscribe"
    case listUnsubscribePost = "List-Unsubscribe-Post"
    case messageContext = "Message-Context"
    case messageID = "Message-ID"
    case messageType = "Message-Type"
    case mIMEVersion = "MIME-Version"
    case mMHSExemptedAddress = "MMHS-Exempted-Address"
    case mMHSExtendedAuthorisationInfo = "MMHS-Extended-Authorisation-Info"
    case mMHSSubjectIndicatorCodes = "MMHS-Subject-Indicator-Codes"
    case mMHSHandlingInstructions = "MMHS-Handling-Instructions"
    case mMHSMessageInstructions = "MMHS-Message-Instructions"
    case mMHSCodressMessageIndicator = "MMHS-Codress-Message-Indicator"
    case mMHSOriginatorReference = "MMHS-Originator-Reference"
    case mMHSPrimaryPrecedence = "MMHS-Primary-Precedence"
    case mMHSCopyPrecedence = "MMHS-Copy-Precedence"
    case mMHSMessageType = "MMHS-Message-Type"
    case mMHSOtherRecipientsIndicatorTo = "MMHS-Other-Recipients-Indicator-To"
    case mMHSOtherRecipientsIndicatorCC = "MMHS-Other-Recipients-Indicator-CC"
    case mMHSAcp127MessageIdentifier = "MMHS-Acp127-Message-Identifier"
    case mMHSOriginatorPLAD = "MMHS-Originator-PLAD"
    case mTPriority = "MT-Priority"
    case newsgroups = "Newsgroups"
    case nNTPPostingDate = "NNTP-Posting-Date"
    case nNTPPostingHost = "NNTP-Posting-Host"
    case obsoletes = "Obsoletes"
    case organization = "Organization"
    case originalEncodedInformationTypes = "Original-Encoded-Information-Types"
    case originalFrom = "Original-From"
    case originalMessageID = "Original-Message-ID"
    case originalRecipient = "Original-Recipient"
    case originalSender = "Original-Sender"
    case originatorReturnAddress = "Originator-Return-Address"
    case originalSubject = "Original-Subject"
    case path = "Path"
    case pICSLabel = "PICS-Label"
    case postingVersion = "Posting-Version"
    case preventNonDeliveryReport = "Prevent-NonDelivery-Report"
    case priority = "Priority"
    case received = "Received"
    case receivedSPF = "Received-SPF"
    case references = "References"
    case relayVersion = "Relay-Version"
    case replyBy = "Reply-By"
    case replyTo = "Reply-To"
    case requireRecipientValidSince = "Require-Recipient-Valid-Since"
    case resentBcc = "Resent-Bcc"
    case resentCc = "Resent-Cc"
    case resentDate = "Resent-Date"
    case resentFrom = "Resent-From"
    case resentMessageID = "Resent-Message-ID"
    case resentReplyTo = "Resent-Reply-To"
    case resentSender = "Resent-Sender"
    case resentTo = "Resent-To"
    case returnPath = "Return-Path"
    case seeAlso = "See-Also"
    case sender = "Sender"
    case sensitivity = "Sensitivity"
    case solicitation = "Solicitation"
    case subject = "Subject"
    case summary = "Summary"
    case supersedes = "Supersedes"
    case tLSReportDomain = "TLS-Report-Domain"
    case tLSReportSubmitter = "TLS-Report-Submitter"
    case tLSRequired = "TLS-Required"
    case to = "To"
    case userAgent = "User-Agent"
    case vBRInfo = "VBR-Info"
    case x400ContentIdentifier = "X400-Content-Identifier"
    case x400ContentReturn = "X400-Content-Return"
    case x400ContentType = "X400-Content-Type"
    case x400MTSIdentifier = "X400-MTS-Identifier"
    case x400Originator = "X400-Originator"
    case x400Received = "X400-Received"
    case x400Recipients = "X400-Recipients"
    case x400Trace = "X400-Trace"
    case xrefcase = "Xrefcase"
    /// Provisional Message Header Field Names
    case apparentlyTo = "Apparently-To"
    case author = "Author"
    case eDIINTFeatures = "EDIINT-Features"
    case eesstVersion = "Eesst-Version"
    case errorsTo = "Errors-To"
    case formSub = "Form-Sub"
    case jabberID = "Jabber-ID"
    case mMHSAuthorizingUsers = "MMHS-Authorizing-Users"
    case privicon = "Privicon"
    case sIOLabel = "SIO-Label"
    case sIOLabelHistory = "SIO-Label-History"
    case xArchivedAt = "X-Archived-At"
    case xMittente = "X-Mittente"
    case xPGPSig = "X-PGP-Sig"
    case xRicevuta = "X-Ricevuta"
    case xRiferimentoMessageID = "X-Riferimento-Message-ID"
    case xTipoRicevuta = "X-TipoRicevuta"
    case xTrasporto = "X-Trasporto"
    case xVerificaSicurezza = "X-VerificaSicurezza"
}
